summaryrefslogtreecommitdiff
path: root/test/parallel/test-cluster-worker-kill.js
diff options
context:
space:
mode:
authorMichael Dawson <mdawson@devrus.com>2020-12-10 16:53:44 -0500
committerMichael Dawson <mdawson@devrus.com>2021-01-05 15:41:45 -0500
commit15164cebcebfcad9822d3f065234a8c1511776a4 (patch)
treef9ce2f183ba5af0ff50e104d72af58dbbc40c943 /test/parallel/test-cluster-worker-kill.js
parent3c49ee298fd52295f4cff301a739d43b3ecf0d24 (diff)
downloadnode-new-15164cebcebfcad9822d3f065234a8c1511776a4.tar.gz
lib,src: update cluster to use Parent
Doc deprecate isMaster and setupMaster in favor of isPrimary and setupPrimary. Signed-off-by: Michael Dawson <mdawson@devrus.com> PR-URL: https://github.com/nodejs/node/pull/36478 Reviewed-By: James M Snell <jasnell@gmail.com> Reviewed-By: Rich Trott <rtrott@gmail.com> Reviewed-By: Myles Borins <myles.borins@gmail.com> Reviewed-By: Matteo Collina <matteo.collina@gmail.com> Reviewed-By: Michaƫl Zasso <targos@protonmail.com> Reviewed-By: Beth Griggs <bgriggs@redhat.com>
Diffstat (limited to 'test/parallel/test-cluster-worker-kill.js')
-rw-r--r--test/parallel/test-cluster-worker-kill.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/parallel/test-cluster-worker-kill.js b/test/parallel/test-cluster-worker-kill.js
index 0cd6d0321c..9fcb924149 100644
--- a/test/parallel/test-cluster-worker-kill.js
+++ b/test/parallel/test-cluster-worker-kill.js
@@ -22,7 +22,7 @@
'use strict';
// test-cluster-worker-kill.js
// verifies that, when a child process is killed (we use SIGKILL)
// - the parent receives the proper events in the proper order, no duplicates
// - the exitCode and signalCode are correct in the 'exit' event
// - the worker.exitedAfterDisconnect flag, and worker.state are correct
// - the worker process actually goes away
@@ -38,7 +38,7 @@ if (cluster.isWorker) {
server.once('listening', common.mustCall(() => { }));
server.listen(0, '127.0.0.1');
-} else if (cluster.isMaster) {
+} else if (cluster.isPrimary) {
const KILL_SIGNAL = 'SIGKILL';
const expected_results = {
@@ -22,7 +22,7 @@
// test-cluster-worker-kill.js
// verifies that, when a child process is killed (we use SIGKILL)
-// - the parent receives the proper events in the proper order, no duplicates
+// - the primary receives the proper events in the proper order, no duplicates
// - the exitCode and signalCode are correct in the 'exit' event
// - the worker.exitedAfterDisconnect flag, and worker.state are correct